[Libreoffice-commits] core.git: toolkit/inc toolkit/source
Noel Grandin
noel at peralex.com
Mon Nov 9 01:39:57 PST 2015
toolkit/inc/helper/unopropertyarrayhelper.hxx | 8
toolkit/inc/helper/unowrapper.hxx | 18
toolkit/source/awt/animatedimagespeer.cxx | 2
toolkit/source/awt/asynccallback.cxx | 10
toolkit/source/awt/scrollabledialog.cxx | 4
toolkit/source/awt/stylesettings.hxx | 222 +-
toolkit/source/awt/vclxbitmap.cxx | 36
toolkit/source/awt/vclxcontainer.cxx | 58
toolkit/source/awt/vclxdevice.cxx | 96
toolkit/source/awt/vclxfont.cxx | 48
toolkit/source/awt/vclxgraphics.cxx | 6
toolkit/source/awt/vclxpointer.cxx | 6
toolkit/source/awt/vclxprinter.cxx | 72
toolkit/source/awt/vclxregion.cxx | 44
toolkit/source/awt/vclxsystemdependentwindow.cxx | 24
toolkit/source/awt/vclxtabpagecontainer.cxx | 30
toolkit/source/awt/vclxtoolkit.cxx | 190 -
toolkit/source/awt/vclxtopwindow.cxx | 34
toolkit/source/awt/vclxwindow.cxx | 258 +-
toolkit/source/awt/vclxwindow1.cxx | 10
toolkit/source/awt/vclxwindows.cxx | 1072 +++++-----
toolkit/source/awt/vclxwindows_internal.hxx | 4
toolkit/source/controls/accessiblecontrolcontext.cxx | 4
toolkit/source/controls/animatedimages.cxx | 2
toolkit/source/controls/controlmodelcontainerbase.cxx | 24
toolkit/source/controls/controlmodelcontainerbase_internal.hxx | 2
toolkit/source/controls/dialogcontrol.cxx | 28
toolkit/source/controls/eventcontainer.cxx | 4
toolkit/source/controls/geometrycontrolmodel.cxx | 36
toolkit/source/controls/grid/defaultgriddatamodel.cxx | 6
toolkit/source/controls/grid/gridcolumn.cxx | 30
toolkit/source/controls/grid/gridcolumn.hxx | 92
toolkit/source/controls/grid/gridcontrol.cxx | 20
toolkit/source/controls/grid/gridcontrol.hxx | 74
toolkit/source/controls/grid/grideventforwarder.hxx | 20
toolkit/source/controls/grid/initguard.hxx | 2
toolkit/source/controls/roadmapcontrol.cxx | 8
toolkit/source/controls/roadmapentry.cxx | 32
toolkit/source/controls/stdtabcontrollermodel.cxx | 94
toolkit/source/controls/tabpagecontainer.cxx | 22
toolkit/source/controls/tabpagemodel.cxx | 20
toolkit/source/controls/tkscrollbar.cxx | 48
toolkit/source/controls/tkspinbutton.cxx | 2
toolkit/source/controls/tree/treecontrol.cxx | 8
toolkit/source/controls/tree/treecontrol.hxx | 10
toolkit/source/controls/tree/treedatamodel.cxx | 50
toolkit/source/controls/unocontrolbase.cxx | 62
toolkit/source/controls/unocontrolcontainer.cxx | 20
toolkit/source/controls/unocontrolcontainermodel.cxx | 14
toolkit/source/controls/unocontrolmodel.cxx | 198 -
toolkit/source/controls/unocontrols.cxx | 78
toolkit/source/helper/accessibilityclient.cxx | 24
toolkit/source/helper/listenermultiplexer.cxx | 182 -
toolkit/source/helper/property.cxx | 40
toolkit/source/helper/unopropertyarrayhelper.cxx | 14
toolkit/source/helper/unowrapper.cxx | 26
toolkit/source/helper/vclunohelper.cxx | 265 +-
57 files changed, 1896 insertions(+), 1917 deletions(-)
New commits:
commit 4a00be7ade3235e18cab7706bcfe9a1adccb2462
Author: Noel Grandin <noel at peralex.com>
Date: Mon Nov 9 09:05:08 2015 +0200
com::sun::star->css in toolkit/
Change-Id: Ia8feca46fa64a300235730e1248fa5fda0783ba2
Reviewed-on: https://gerrit.libreoffice.org/19853
Tested-by: Jenkins <ci at libreoffice.org>
Reviewed-by: Noel Grandin <noelgrandin at gmail.com>
diff --git a/toolkit/inc/helper/unopropertyarrayhelper.hxx b/toolkit/inc/helper/unopropertyarrayhelper.hxx
index 3632da5..bbe53a4 100644
--- a/toolkit/inc/helper/unopropertyarrayhelper.hxx
+++ b/toolkit/inc/helper/unopropertyarrayhelper.hxx
@@ -38,16 +38,16 @@ protected:
bool ImplHasProperty( sal_uInt16 nPropId ) const;
public:
- UnoPropertyArrayHelper( const ::com::sun::star::uno::Sequence<sal_Int32>& rIDs );
+ UnoPropertyArrayHelper( const css::uno::Sequence<sal_Int32>& rIDs );
UnoPropertyArrayHelper( const std::list< sal_uInt16 > &rIDs );
// ::cppu::IPropertyArrayHelper
sal_Bool SAL_CALL fillPropertyMembersByHandle( OUString * pPropName, sal_Int16 * pAttributes, sal_Int32 nHandle ) override;
- ::com::sun::star::uno::Sequence< ::com::sun::star::beans::Property > SAL_CALL getProperties() override;
- ::com::sun::star::beans::Property SAL_CALL getPropertyByName(const OUString& rPropertyName) throw (::com::sun::star::beans::UnknownPropertyException) override;
+ css::uno::Sequence< css::beans::Property > SAL_CALL getProperties() override;
+ css::beans::Property SAL_CALL getPropertyByName(const OUString& rPropertyName) throw (css::beans::UnknownPropertyException) override;
sal_Bool SAL_CALL hasPropertyByName(const OUString& rPropertyName) override;
sal_Int32 SAL_CALL getHandleByName( const OUString & rPropertyName ) override;
- sal_Int32 SAL_CALL fillHandles( sal_Int32* pHandles, const ::com::sun::star::uno::Sequence< OUString > & rPropNames ) override;
+ sal_Int32 SAL_CALL fillHandles( sal_Int32* pHandles, const css::uno::Sequence< OUString > & rPropNames ) override;
};
diff --git a/toolkit/inc/helper/unowrapper.hxx b/toolkit/inc/helper/unowrapper.hxx
index 3efe623..f110e3c 100644
--- a/toolkit/inc/helper/unowrapper.hxx
+++ b/toolkit/inc/helper/unowrapper.hxx
@@ -36,29 +36,29 @@
class UnoWrapper : public UnoWrapperBase
{
private:
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XToolkit> mxToolkit;
- ::toolkit::AccessibilityClient maAccessibleFactoryAccess;
+ css::uno::Reference< css::awt::XToolkit> mxToolkit;
+ ::toolkit::AccessibilityClient maAccessibleFactoryAccess;
public:
- UnoWrapper( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XToolkit>& rxToolkit );
+ UnoWrapper( const css::uno::Reference< css::awt::XToolkit>& rxToolkit );
virtual void Destroy() override;
// Toolkit
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XToolkit> GetVCLToolkit() override;
+ virtual css::uno::Reference< css::awt::XToolkit> GetVCLToolkit() override;
// Graphics
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XGraphics> CreateGraphics( OutputDevice* pOutDev ) override;
- virtual void ReleaseAllGraphics( OutputDevice* pOutDev ) override;
+ virtual css::uno::Reference< css::awt::XGraphics> CreateGraphics( OutputDevice* pOutDev ) override;
+ virtual void ReleaseAllGraphics( OutputDevice* pOutDev ) override;
// Window
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer> GetWindowInterface( vcl::Window* pWindow, bool bCreate ) override;
- virtual void SetWindowInterface( vcl::Window* pWindow, ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer> xIFace ) override;
+ virtual css::uno::Reference< css::awt::XWindowPeer> GetWindowInterface( vcl::Window* pWindow, bool bCreate ) override;
+ virtual void SetWindowInterface( vcl::Window* pWindow, css::uno::Reference< css::awt::XWindowPeer> xIFace ) override;
void WindowDestroyed( vcl::Window* pWindow ) override;
// Accessibility
- virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible >
+ virtual css::uno::Reference< css::accessibility::XAccessible >
CreateAccessible( Menu* pMenu, bool bIsMenuBar ) override;
private:
diff --git a/toolkit/source/awt/animatedimagespeer.cxx b/toolkit/source/awt/animatedimagespeer.cxx
index f5631c0..14876ea 100644
--- a/toolkit/source/awt/animatedimagespeer.cxx
+++ b/toolkit/source/awt/animatedimagespeer.cxx
@@ -190,7 +190,7 @@ namespace toolkit
{
// collect the image sizes of the different image sets
const Reference< XComponentContext > xContext( ::comphelper::getProcessComponentContext() );
- const Reference< XGraphicProvider > xGraphicProvider( com::sun::star::graphic::GraphicProvider::create(xContext) );
+ const Reference< XGraphicProvider > xGraphicProvider( css::graphic::GraphicProvider::create(xContext) );
const bool isHighContrast = pThrobber->GetSettings().GetStyleSettings().GetHighContrastMode();
diff --git a/toolkit/source/awt/asynccallback.cxx b/toolkit/source/awt/asynccallback.cxx
index 776d9c6..9faaf0c 100644
--- a/toolkit/source/awt/asynccallback.cxx
+++ b/toolkit/source/awt/asynccallback.cxx
@@ -42,13 +42,13 @@ class AsyncCallback:
public:
AsyncCallback() {}
- // ::com::sun::star::lang::XServiceInfo:
+ // css::lang::XServiceInfo:
virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override;
virtual sal_Bool SAL_CALL supportsService(const OUString & ServiceName) throw (css::uno::RuntimeException, std::exception) override;
virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override;
- // ::com::sun::star::awt::XRequestCallback:
- virtual void SAL_CALL addCallback(const css::uno::Reference< css::awt::XCallback > & xCallback, const ::com::sun::star::uno::Any & aData) throw (css::uno::RuntimeException, std::exception) override;
+ // css::awt::XRequestCallback:
+ virtual void SAL_CALL addCallback(const css::uno::Reference< css::awt::XCallback > & xCallback, const css::uno::Any & aData) throw (css::uno::RuntimeException, std::exception) override;
private:
@@ -84,8 +84,8 @@ css::uno::Sequence< OUString > SAL_CALL AsyncCallback::getSupportedServiceNames(
return s;
}
-// ::com::sun::star::awt::XRequestCallback:
-void SAL_CALL AsyncCallback::addCallback(const css::uno::Reference< css::awt::XCallback > & xCallback, const ::com::sun::star::uno::Any & aData) throw (css::uno::RuntimeException, std::exception)
+// css::awt::XRequestCallback:
+void SAL_CALL AsyncCallback::addCallback(const css::uno::Reference< css::awt::XCallback > & xCallback, const css::uno::Any & aData) throw (css::uno::RuntimeException, std::exception)
{
if ( Application::IsInMain() )
{
diff --git a/toolkit/source/awt/scrollabledialog.cxx b/toolkit/source/awt/scrollabledialog.cxx
index cd408d3..cc2c771 100644
--- a/toolkit/source/awt/scrollabledialog.cxx
+++ b/toolkit/source/awt/scrollabledialog.cxx
@@ -26,8 +26,8 @@ namespace toolkit
// Using WB_AUTOHSCROLL, WB_AUTOVSCROLL here sucks big time, there is a
// problem in the toolkit class where there are some clashing IDs
-// ( ::com::sun::star::awt::VclWindowPeerAttribute::VSCROLL has the same value
-// as ::com::sun::star::awt::WindowAttribute::NODECORATION and they are used
+// ( css::awt::VclWindowPeerAttribute::VSCROLL has the same value
+// as css::awt::WindowAttribute::NODECORATION and they are used
// in the same bitmap :-( WB_VSCROLL & WB_HSCROLL apparently are only for
// child classes ( whole thing is a mess if you ask me )
template< class T>
diff --git a/toolkit/source/awt/stylesettings.hxx b/toolkit/source/awt/stylesettings.hxx
index 05a337c..7237ede 100644
--- a/toolkit/source/awt/stylesettings.hxx
+++ b/toolkit/source/awt/stylesettings.hxx
@@ -42,7 +42,7 @@ namespace toolkit
//= WindowStyleSettings
struct WindowStyleSettings_Data;
- typedef ::cppu::WeakImplHelper < ::com::sun::star::awt::XStyleSettings
+ typedef ::cppu::WeakImplHelper < css::awt::XStyleSettings
> WindowStyleSettings_Base;
class WindowStyleSettings : public WindowStyleSettings_Base
{
@@ -53,116 +53,116 @@ namespace toolkit
void dispose();
// XStyleSettings
- virtual ::sal_Int32 SAL_CALL getActiveBorderColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setActiveBorderColor( ::sal_Int32 _activebordercolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getActiveColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setActiveColor( ::sal_Int32 _activecolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getActiveTabColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setActiveTabColor( ::sal_Int32 _activetabcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getActiveTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setActiveTextColor( ::sal_Int32 _activetextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getButtonRolloverTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setButtonRolloverTextColor( ::sal_Int32 _buttonrollovertextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getButtonTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setButtonTextColor( ::sal_Int32 _buttontextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getCheckedColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setCheckedColor( ::sal_Int32 _checkedcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDarkShadowColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDarkShadowColor( ::sal_Int32 _darkshadowcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDeactiveBorderColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDeactiveBorderColor( ::sal_Int32 _deactivebordercolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDeactiveColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDeactiveColor( ::sal_Int32 _deactivecolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDeactiveTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDeactiveTextColor( ::sal_Int32 _deactivetextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDialogColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDialogColor( ::sal_Int32 _dialogcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDialogTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDialogTextColor( ::sal_Int32 _dialogtextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getDisableColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setDisableColor( ::sal_Int32 _disablecolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getFaceColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFaceColor( ::sal_Int32 _facecolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getFaceGradientColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getFieldColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFieldColor( ::sal_Int32 _fieldcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getFieldRolloverTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFieldRolloverTextColor( ::sal_Int32 _fieldrollovertextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getFieldTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFieldTextColor( ::sal_Int32 _fieldtextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getGroupTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setGroupTextColor( ::sal_Int32 _grouptextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getHelpColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHelpColor( ::sal_Int32 _helpcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getHelpTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHelpTextColor( ::sal_Int32 _helptextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getHighlightColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHighlightColor( ::sal_Int32 _highlightcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getHighlightTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHighlightTextColor( ::sal_Int32 _highlighttextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getInactiveTabColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setInactiveTabColor( ::sal_Int32 _inactivetabcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getInfoTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setInfoTextColor( ::sal_Int32 _infotextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getLabelTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setLabelTextColor( ::sal_Int32 _labeltextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getLightColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setLightColor( ::sal_Int32 _lightcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuBarColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuBarColor( ::sal_Int32 _menubarcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuBarTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuBarTextColor( ::sal_Int32 _menubartextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuBorderColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuBorderColor( ::sal_Int32 _menubordercolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuColor( ::sal_Int32 _menucolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuHighlightColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuHighlightColor( ::sal_Int32 _menuhighlightcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuHighlightTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuHighlightTextColor( ::sal_Int32 _menuhighlighttextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMenuTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuTextColor( ::sal_Int32 _menutextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getMonoColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMonoColor( ::sal_Int32 _monocolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getRadioCheckTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setRadioCheckTextColor( ::sal_Int32 _radiochecktextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getSeparatorColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getShadowColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setShadowColor( ::sal_Int32 _shadowcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getWindowColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setWindowColor( ::sal_Int32 _windowcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getWindowTextColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setWindowTextColor( ::sal_Int32 _windowtextcolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::sal_Int32 SAL_CALL getWorkspaceColor() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setWorkspaceColor( ::sal_Int32 _workspacecolor ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual sal_Bool SAL_CALL getHighContrastMode() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHighContrastMode( sal_Bool _highcontrastmode ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getApplicationFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setApplicationFont( const ::com::sun::star::awt::FontDescriptor& _applicationfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getHelpFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setHelpFont( const ::com::sun::star::awt::FontDescriptor& _helpfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getTitleFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setTitleFont( const ::com::sun::star::awt::FontDescriptor& _titlefont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getFloatTitleFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFloatTitleFont( const ::com::sun::star::awt::FontDescriptor& _floattitlefont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getMenuFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setMenuFont( const ::com::sun::star::awt::FontDescriptor& _menufont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getToolFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setToolFont( const ::com::sun::star::awt::FontDescriptor& _toolfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getGroupFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setGroupFont( const ::com::sun::star::awt::FontDescriptor& _groupfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getLabelFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setLabelFont( const ::com::sun::star::awt::FontDescriptor& _labelfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getInfoFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setInfoFont( const ::com::sun::star::awt::FontDescriptor& _infofont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getRadioCheckFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setRadioCheckFont( const ::com::sun::star::awt::FontDescriptor& _radiocheckfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getPushButtonFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setPushButtonFont( const ::com::sun::star::awt::FontDescriptor& _pushbuttonfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual ::com::sun::star::awt::FontDescriptor SAL_CALL getFieldFont() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL setFieldFont( const ::com::sun::star::awt::FontDescriptor& _fieldfont ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL addStyleChangeListener( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XStyleChangeListener >& Listener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
- virtual void SAL_CALL removeStyleChangeListener( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XStyleChangeListener >& Listener ) throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getActiveBorderColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setActiveBorderColor( ::sal_Int32 _activebordercolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getActiveColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setActiveColor( ::sal_Int32 _activecolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getActiveTabColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setActiveTabColor( ::sal_Int32 _activetabcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getActiveTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setActiveTextColor( ::sal_Int32 _activetextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getButtonRolloverTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setButtonRolloverTextColor( ::sal_Int32 _buttonrollovertextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getButtonTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setButtonTextColor( ::sal_Int32 _buttontextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getCheckedColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setCheckedColor( ::sal_Int32 _checkedcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDarkShadowColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDarkShadowColor( ::sal_Int32 _darkshadowcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDeactiveBorderColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDeactiveBorderColor( ::sal_Int32 _deactivebordercolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDeactiveColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDeactiveColor( ::sal_Int32 _deactivecolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDeactiveTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDeactiveTextColor( ::sal_Int32 _deactivetextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDialogColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDialogColor( ::sal_Int32 _dialogcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDialogTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDialogTextColor( ::sal_Int32 _dialogtextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getDisableColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setDisableColor( ::sal_Int32 _disablecolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getFaceColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFaceColor( ::sal_Int32 _facecolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getFaceGradientColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getFieldColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFieldColor( ::sal_Int32 _fieldcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getFieldRolloverTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFieldRolloverTextColor( ::sal_Int32 _fieldrollovertextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getFieldTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFieldTextColor( ::sal_Int32 _fieldtextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getGroupTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setGroupTextColor( ::sal_Int32 _grouptextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHelpColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHelpColor( ::sal_Int32 _helpcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHelpTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHelpTextColor( ::sal_Int32 _helptextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHighlightColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHighlightColor( ::sal_Int32 _highlightcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getHighlightTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHighlightTextColor( ::sal_Int32 _highlighttextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getInactiveTabColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setInactiveTabColor( ::sal_Int32 _inactivetabcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getInfoTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setInfoTextColor( ::sal_Int32 _infotextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getLabelTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setLabelTextColor( ::sal_Int32 _labeltextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getLightColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setLightColor( ::sal_Int32 _lightcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuBarColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuBarColor( ::sal_Int32 _menubarcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuBarTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuBarTextColor( ::sal_Int32 _menubartextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuBorderColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuBorderColor( ::sal_Int32 _menubordercolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuColor( ::sal_Int32 _menucolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuHighlightColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuHighlightColor( ::sal_Int32 _menuhighlightcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuHighlightTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuHighlightTextColor( ::sal_Int32 _menuhighlighttextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMenuTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuTextColor( ::sal_Int32 _menutextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getMonoColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMonoColor( ::sal_Int32 _monocolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getRadioCheckTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setRadioCheckTextColor( ::sal_Int32 _radiochecktextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getSeparatorColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getShadowColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setShadowColor( ::sal_Int32 _shadowcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getWindowColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setWindowColor( ::sal_Int32 _windowcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getWindowTextColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setWindowTextColor( ::sal_Int32 _windowtextcolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual ::sal_Int32 SAL_CALL getWorkspaceColor() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setWorkspaceColor( ::sal_Int32 _workspacecolor ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual sal_Bool SAL_CALL getHighContrastMode() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHighContrastMode( sal_Bool _highcontrastmode ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getApplicationFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setApplicationFont( const css::awt::FontDescriptor& _applicationfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getHelpFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setHelpFont( const css::awt::FontDescriptor& _helpfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getTitleFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setTitleFont( const css::awt::FontDescriptor& _titlefont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getFloatTitleFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFloatTitleFont( const css::awt::FontDescriptor& _floattitlefont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getMenuFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setMenuFont( const css::awt::FontDescriptor& _menufont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getToolFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setToolFont( const css::awt::FontDescriptor& _toolfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getGroupFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setGroupFont( const css::awt::FontDescriptor& _groupfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getLabelFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setLabelFont( const css::awt::FontDescriptor& _labelfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getInfoFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setInfoFont( const css::awt::FontDescriptor& _infofont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getRadioCheckFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setRadioCheckFont( const css::awt::FontDescriptor& _radiocheckfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getPushButtonFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setPushButtonFont( const css::awt::FontDescriptor& _pushbuttonfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual css::awt::FontDescriptor SAL_CALL getFieldFont() throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL setFieldFont( const css::awt::FontDescriptor& _fieldfont ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL addStyleChangeListener( const css::uno::Reference< css::awt::XStyleChangeListener >& Listener ) throw (css::uno::RuntimeException, std::exception) override;
+ virtual void SAL_CALL removeStyleChangeListener( const css::uno::Reference< css::awt::XStyleChangeListener >& Listener ) throw (css::uno::RuntimeException, std::exception) override;
private:
std::unique_ptr< WindowStyleSettings_Data > m_pData;
diff --git a/toolkit/source/awt/vclxbitmap.cxx b/toolkit/source/awt/vclxbitmap.cxx
index 670dcd5..daa0cab 100644
--- a/toolkit/source/awt/vclxbitmap.cxx
+++ b/toolkit/source/awt/vclxbitmap.cxx
@@ -29,52 +29,52 @@
// class VCLXBitmap
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXBitmap::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXBitmap::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XBitmap* >(this)),
- (static_cast< ::com::sun::star::awt::XDisplayBitmap* >(this)),
- (static_cast< ::com::sun::star::lang::XUnoTunnel* >(this)),
- (static_cast< ::com::sun::star::lang::XTypeProvider* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XBitmap* >(this)),
+ (static_cast< css::awt::XDisplayBitmap* >(this)),
+ (static_cast< css::lang::XUnoTunnel* >(this)),
+ (static_cast< css::lang::XTypeProvider* >(this)) );
return (aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType ));
}
-// ::com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
IMPL_XUNOTUNNEL( VCLXBitmap )
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXBitmap )
- cppu::UnoType<com::sun::star::awt::XBitmap>::get(),
- cppu::UnoType<com::sun::star::awt::XDisplayBitmap>::get()
+ cppu::UnoType<css::awt::XBitmap>::get(),
+ cppu::UnoType<css::awt::XDisplayBitmap>::get()
IMPL_XTYPEPROVIDER_END
-// ::com::sun::star::awt::XBitmap
-::com::sun::star::awt::Size VCLXBitmap::getSize() throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XBitmap
+css::awt::Size VCLXBitmap::getSize() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
- ::com::sun::star::awt::Size aSize( maBitmap.GetSizePixel().Width(), maBitmap.GetSizePixel().Height() );
+ css::awt::Size aSize( maBitmap.GetSizePixel().Width(), maBitmap.GetSizePixel().Height() );
return aSize;
}
-::com::sun::star::uno::Sequence< sal_Int8 > VCLXBitmap::getDIB() throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< sal_Int8 > VCLXBitmap::getDIB() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
SvMemoryStream aMem;
WriteDIB(maBitmap.GetBitmap(), aMem, false, true);
- return ::com::sun::star::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
+ return css::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
}
-::com::sun::star::uno::Sequence< sal_Int8 > VCLXBitmap::getMaskDIB() throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< sal_Int8 > VCLXBitmap::getMaskDIB() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
SvMemoryStream aMem;
WriteDIB(maBitmap.GetMask(), aMem, false, true);
- return ::com::sun::star::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
+ return css::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
}
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/toolkit/source/awt/vclxfont.cxx b/toolkit/source/awt/vclxfont.cxx
index acdae57..83e8119 100644
--- a/toolkit/source/awt/vclxfont.cxx
+++ b/toolkit/source/awt/vclxfont.cxx
@@ -43,7 +43,7 @@ VCLXFont::~VCLXFont()
delete mpFontMetric;
}
-void VCLXFont::Init( ::com::sun::star::awt::XDevice& rxDev, const vcl::Font& rFont )
+void VCLXFont::Init( css::awt::XDevice& rxDev, const vcl::Font& rFont )
{
mxDevice = &rxDev;
@@ -70,27 +70,27 @@ bool VCLXFont::ImplAssertValidFontMetric()
}
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXFont::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXFont::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XFont* >(this)),
- (static_cast< ::com::sun::star::awt::XFont2* >(this)),
- (static_cast< ::com::sun::star::lang::XUnoTunnel* >(this)),
- (static_cast< ::com::sun::star::lang::XTypeProvider* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XFont* >(this)),
+ (static_cast< css::awt::XFont2* >(this)),
+ (static_cast< css::lang::XUnoTunnel* >(this)),
+ (static_cast< css::lang::XTypeProvider* >(this)) );
return (aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType ));
}
-// ::com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
IMPL_XUNOTUNNEL( VCLXFont )
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXFont )
- cppu::UnoType<com::sun::star::awt::XFont2>::get()
+ cppu::UnoType<css::awt::XFont2>::get()
IMPL_XTYPEPROVIDER_END
-::com::sun::star::awt::FontDescriptor VCLXFont::getFontDescriptor( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::FontDescriptor VCLXFont::getFontDescriptor( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -98,17 +98,17 @@ IMPL_XTYPEPROVIDER_END
}
-::com::sun::star::awt::SimpleFontMetric VCLXFont::getFontMetric( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::SimpleFontMetric VCLXFont::getFontMetric( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
- ::com::sun::star::awt::SimpleFontMetric aFM;
+ css::awt::SimpleFontMetric aFM;
if ( ImplAssertValidFontMetric() )
aFM = VCLUnoHelper::CreateFontMetric( *mpFontMetric );
return aFM;
}
-sal_Int16 VCLXFont::getCharWidth( sal_Unicode c ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int16 VCLXFont::getCharWidth( sal_Unicode c ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -127,11 +127,11 @@ sal_Int16 VCLXFont::getCharWidth( sal_Unicode c ) throw(::com::sun::star::uno::R
return nRet;
}
-::com::sun::star::uno::Sequence< sal_Int16 > VCLXFont::getCharWidths( sal_Unicode nFirst, sal_Unicode nLast ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< sal_Int16 > VCLXFont::getCharWidths( sal_Unicode nFirst, sal_Unicode nLast ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
- ::com::sun::star::uno::Sequence<sal_Int16> aSeq;
+ css::uno::Sequence<sal_Int16> aSeq;
OutputDevice* pOutDev = VCLUnoHelper::GetOutputDevice( mxDevice );
if ( pOutDev )
{
@@ -139,7 +139,7 @@ sal_Int16 VCLXFont::getCharWidth( sal_Unicode c ) throw(::com::sun::star::uno::R
pOutDev->SetFont( maFont );
sal_Int16 nCount = nLast-nFirst + 1;
- aSeq = ::com::sun::star::uno::Sequence<sal_Int16>( nCount );
+ aSeq = css::uno::Sequence<sal_Int16>( nCount );
for ( sal_uInt16 n = 0; n < nCount; n++ )
{
aSeq.getArray()[n] = sal::static_int_cast< sal_Int16 >(
@@ -152,7 +152,7 @@ sal_Int16 VCLXFont::getCharWidth( sal_Unicode c ) throw(::com::sun::star::uno::R
return aSeq;
}
-sal_Int32 VCLXFont::getStringWidth( const OUString& str ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int32 VCLXFont::getStringWidth( const OUString& str ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -168,7 +168,7 @@ sal_Int32 VCLXFont::getStringWidth( const OUString& str ) throw(::com::sun::star
return nRet;
}
-sal_Int32 VCLXFont::getStringWidthArray( const OUString& str, ::com::sun::star::uno::Sequence< sal_Int32 >& rDXArray ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int32 VCLXFont::getStringWidthArray( const OUString& str, css::uno::Sequence< sal_Int32 >& rDXArray ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -180,7 +180,7 @@ sal_Int32 VCLXFont::getStringWidthArray( const OUString& str, ::com::sun::star::
pOutDev->SetFont( maFont );
std::unique_ptr<long []> pDXA(new long[str.getLength()]);
nRet = pOutDev->GetTextArray( str, pDXA.get() );
- rDXArray = ::com::sun::star::uno::Sequence<sal_Int32>( str.getLength() );
+ rDXArray = css::uno::Sequence<sal_Int32>( str.getLength() );
for(int i = 0; i < str.getLength(); i++)
{
rDXArray[i] = pDXA[i];
@@ -190,14 +190,14 @@ sal_Int32 VCLXFont::getStringWidthArray( const OUString& str, ::com::sun::star::
return nRet;
}
-void VCLXFont::getKernPairs( ::com::sun::star::uno::Sequence< sal_Unicode >& /*rnChars1*/, ::com::sun::star::uno::Sequence< sal_Unicode >& /*rnChars2*/, ::com::sun::star::uno::Sequence< sal_Int16 >& /*rnKerns*/ ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXFont::getKernPairs( css::uno::Sequence< sal_Unicode >& /*rnChars1*/, css::uno::Sequence< sal_Unicode >& /*rnChars2*/, css::uno::Sequence< sal_Int16 >& /*rnKerns*/ ) throw(css::uno::RuntimeException, std::exception)
{
// NOTE: this empty method is just used for keeping the related UNO-API stable
}
-// ::com::sun::star::awt::XFont2
+// css::awt::XFont2
sal_Bool VCLXFont::hasGlyphs( const OUString& aText )
- throw(::com::sun::star::uno::RuntimeException, std::exception)
+ throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
SolarMutexGuard aSolarGuard;
diff --git a/toolkit/source/awt/vclxgraphics.cxx b/toolkit/source/awt/vclxgraphics.cxx
index 4e2268f..683db6b 100644
--- a/toolkit/source/awt/vclxgraphics.cxx
+++ b/toolkit/source/awt/vclxgraphics.cxx
@@ -43,9 +43,9 @@ using namespace com::sun::star;
uno::Any VCLXGraphics::queryInterface( const uno::Type & rType ) throw(uno::RuntimeException, std::exception)
{
uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XGraphics* >(this)),
- (static_cast< ::com::sun::star::lang::XTypeProvider* >(this)),
- (static_cast< ::com::sun::star::lang::XUnoTunnel* >(this)) );
+ (static_cast< css::awt::XGraphics* >(this)),
+ (static_cast< css::lang::XTypeProvider* >(this)),
+ (static_cast< css::lang::XUnoTunnel* >(this)) );
return (aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType ));
}
diff --git a/toolkit/source/awt/vclxpointer.cxx b/toolkit/source/awt/vclxpointer.cxx
index c6560d8..9e9590f 100644
--- a/toolkit/source/awt/vclxpointer.cxx
+++ b/toolkit/source/awt/vclxpointer.cxx
@@ -30,17 +30,17 @@ VCLXPointer::~VCLXPointer()
{
}
-// ::com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
IMPL_XUNOTUNNEL( VCLXPointer )
-void VCLXPointer::setType( sal_Int32 nType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPointer::setType( sal_Int32 nType ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maPointer = Pointer( (PointerStyle)nType );
}
-sal_Int32 VCLXPointer::getType() throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int32 VCLXPointer::getType() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
diff --git a/toolkit/source/awt/vclxprinter.cxx b/toolkit/source/awt/vclxprinter.cxx
index b5fbf456..314dceb 100644
--- a/toolkit/source/awt/vclxprinter.cxx
+++ b/toolkit/source/awt/vclxprinter.cxx
@@ -40,22 +40,22 @@
#define PROPERTY_Orientation 0
#define PROPERTY_Horizontal 1
-::com::sun::star::beans::Property* ImplGetProperties( sal_uInt16& rElementCount )
+css::beans::Property* ImplGetProperties( sal_uInt16& rElementCount )
{
- static ::com::sun::star::beans::Property* pProperties = NULL;
+ static css::beans::Property* pProperties = NULL;
static sal_uInt16 nElements = 0;
if( !pProperties )
{
::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
if( !pProperties )
{
- static ::com::sun::star::beans::Property aPropTable[] =
+ static css::beans::Property aPropTable[] =
{
- ::com::sun::star::beans::Property( OUString("Orientation"), PROPERTY_Orientation, cppu::UnoType<sal_Int16>::get(), 0 ),
- ::com::sun::star::beans::Property( OUString("Horizontal"), PROPERTY_Horizontal, cppu::UnoType<bool>::get(), 0 )
+ css::beans::Property( OUString("Orientation"), PROPERTY_Orientation, cppu::UnoType<sal_Int16>::get(), 0 ),
+ css::beans::Property( OUString("Horizontal"), PROPERTY_Horizontal, cppu::UnoType<bool>::get(), 0 )
};
pProperties = aPropTable;
- nElements = sizeof( aPropTable ) / sizeof( ::com::sun::star::beans::Property );
+ nElements = sizeof( aPropTable ) / sizeof( css::beans::Property );
}
}
rElementCount = nElements;
@@ -85,7 +85,7 @@ VCLXPrinterPropertySet::~VCLXPrinterPropertySet()
mxPrinter.reset();
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > VCLXPrinterPropertySet::GetDevice()
+css::uno::Reference< css::awt::XDevice > VCLXPrinterPropertySet::GetDevice()
{
if ( !mxPrnDevice.is() )
{
@@ -96,9 +96,9 @@ VCLXPrinterPropertySet::~VCLXPrinterPropertySet()
return mxPrnDevice;
}
-::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > VCLXPrinterPropertySet::getPropertySetInfo( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::beans::XPropertySetInfo > VCLXPrinterPropertySet::getPropertySetInfo( ) throw(css::uno::RuntimeException, std::exception)
{
- static ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
+ static css::uno::Reference< css::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
return xInfo;
}
@@ -111,14 +111,14 @@ VCLXPrinterPropertySet::~VCLXPrinterPropertySet()
if( !pPropertyArrayHelper )
{
sal_uInt16 nElements;
- ::com::sun::star::beans::Property* pProps = ImplGetProperties( nElements );
+ css::beans::Property* pProps = ImplGetProperties( nElements );
pPropertyArrayHelper = new ::cppu::OPropertyArrayHelper( pProps, nElements, sal_False );
}
}
return *pPropertyArrayHelper ;
}
-sal_Bool VCLXPrinterPropertySet::convertFastPropertyValue( ::com::sun::star::uno::Any & rConvertedValue, ::com::sun::star::uno::Any & rOldValue, sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue ) throw (::com::sun::star::lang::IllegalArgumentException)
+sal_Bool VCLXPrinterPropertySet::convertFastPropertyValue( css::uno::Any & rConvertedValue, css::uno::Any & rOldValue, sal_Int32 nHandle, const css::uno::Any& rValue ) throw (css::lang::IllegalArgumentException)
{
::osl::MutexGuard aGuard( Mutex );
@@ -155,7 +155,7 @@ sal_Bool VCLXPrinterPropertySet::convertFastPropertyValue( ::com::sun::star::uno
return bDifferent;
}
-void VCLXPrinterPropertySet::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue ) throw (::com::sun::star::uno::Exception, std::exception)
+void VCLXPrinterPropertySet::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const css::uno::Any& rValue ) throw (css::uno::Exception, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -178,7 +178,7 @@ void VCLXPrinterPropertySet::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle
}
}
-void VCLXPrinterPropertySet::getFastPropertyValue( ::com::sun::star::uno::Any& rValue, sal_Int32 nHandle ) const
+void VCLXPrinterPropertySet::getFastPropertyValue( css::uno::Any& rValue, sal_Int32 nHandle ) const
{
::osl::MutexGuard aGuard( const_cast<VCLXPrinterPropertySet*>(this)->Mutex );
@@ -197,22 +197,22 @@ void VCLXPrinterPropertySet::getFastPropertyValue( ::com::sun::star::uno::Any& r
}
}
-// ::com::sun::star::awt::XPrinterPropertySet
-void VCLXPrinterPropertySet::setHorizontal( sal_Bool bHorizontal ) throw(::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XPrinterPropertySet
+void VCLXPrinterPropertySet::setHorizontal( sal_Bool bHorizontal ) throw(css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
- ::com::sun::star::uno::Any aValue;
+ css::uno::Any aValue;
aValue <<= bHorizontal;
setFastPropertyValue( PROPERTY_Horizontal, aValue );
}
-::com::sun::star::uno::Sequence< OUString > VCLXPrinterPropertySet::getFormDescriptions( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString > VCLXPrinterPropertySet::getFormDescriptions( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
sal_uInt16 nPaperBinCount = GetPrinter()->GetPaperBinCount();
- ::com::sun::star::uno::Sequence< OUString > aDescriptions( nPaperBinCount );
+ css::uno::Sequence< OUString > aDescriptions( nPaperBinCount );
for ( sal_uInt16 n = 0; n < nPaperBinCount; n++ )
{
// Format: <DisplayFormName;FormNameId;DisplayPaperBinName;PaperBinNameId;DisplayPaperName;PaperNameId>
@@ -227,7 +227,7 @@ void VCLXPrinterPropertySet::setHorizontal( sal_Bool bHorizontal ) throw(::com::
return aDescriptions;
}
-void VCLXPrinterPropertySet::selectForm( const OUString& rFormDescription ) throw(::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPrinterPropertySet::selectForm( const OUString& rFormDescription ) throw(css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -237,17 +237,17 @@ void VCLXPrinterPropertySet::selectForm( const OUString& rFormDescription ) thro
GetPrinter()->SetPaperBin( nPaperBin );
}
-::com::sun::star::uno::Sequence< sal_Int8 > VCLXPrinterPropertySet::getBinarySetup( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< sal_Int8 > VCLXPrinterPropertySet::getBinarySetup( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
SvMemoryStream aMem;
aMem.WriteUInt32( BINARYSETUPMARKER );
WriteJobSetup( aMem, GetPrinter()->GetJobSetup() );
- return ::com::sun::star::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
+ return css::uno::Sequence<sal_Int8>( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
}
-void VCLXPrinterPropertySet::setBinarySetup( const ::com::sun::star::uno::Sequence< sal_Int8 >& data ) throw(::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPrinterPropertySet::setBinarySetup( const css::uno::Sequence< sal_Int8 >& data ) throw(css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -276,7 +276,7 @@ VCLXPrinter::~VCLXPrinter()
{
}
-sal_Bool VCLXPrinter::start( const OUString& /*rJobName*/, sal_Int16 /*nCopies*/, sal_Bool /*bCollate*/ ) throw(::com::sun::star::awt::PrinterException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+sal_Bool VCLXPrinter::start( const OUString& /*rJobName*/, sal_Int16 /*nCopies*/, sal_Bool /*bCollate*/ ) throw(css::awt::PrinterException, css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -290,7 +290,7 @@ sal_Bool VCLXPrinter::start( const OUString& /*rJobName*/, sal_Int16 /*nCopies*/
return bDone;
}
-void VCLXPrinter::end( ) throw(::com::sun::star::awt::PrinterException, ::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPrinter::end( ) throw(css::awt::PrinterException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -301,14 +301,14 @@ void VCLXPrinter::end( ) throw(::com::sun::star::awt::PrinterException, ::com::
}
}
-void VCLXPrinter::terminate( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPrinter::terminate( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
mxListener.reset();
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > VCLXPrinter::startPage( ) throw(::com::sun::star::awt::PrinterException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XDevice > VCLXPrinter::startPage( ) throw(css::awt::PrinterException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -319,7 +319,7 @@ void VCLXPrinter::terminate( ) throw(::com::sun::star::uno::RuntimeException, s
return GetDevice();
}
-void VCLXPrinter::endPage( ) throw(::com::sun::star::awt::PrinterException, ::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXPrinter::endPage( ) throw(css::awt::PrinterException, css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -343,8 +343,8 @@ VCLXInfoPrinter::~VCLXInfoPrinter()
{
}
-// ::com::sun::star::awt::XInfoPrinter
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > VCLXInfoPrinter::createDevice( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XInfoPrinter
+css::uno::Reference< css::awt::XDevice > VCLXInfoPrinter::createDevice( ) throw(css::uno::RuntimeException, std::exception)
{
::osl::MutexGuard aGuard( Mutex );
@@ -355,29 +355,29 @@ VCLXInfoPrinter::~VCLXInfoPrinter()
// class VCLXPrinterServer
// ----------------------------------------------------
-// ::com::sun::star::awt::XPrinterServer
-::com::sun::star::uno::Sequence< OUString > VCLXPrinterServer::getPrinterNames( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XPrinterServer
+css::uno::Sequence< OUString > VCLXPrinterServer::getPrinterNames( ) throw(css::uno::RuntimeException, std::exception)
{
const std::vector<OUString>& rQueues = Printer::GetPrinterQueues();
sal_uInt32 nPrinters = rQueues.size();
- ::com::sun::star::uno::Sequence< OUString > aNames( nPrinters );
+ css::uno::Sequence< OUString > aNames( nPrinters );
for ( sal_uInt32 n = 0; n < nPrinters; n++ )
aNames.getArray()[n] = rQueues[n];
return aNames;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XPrinter > VCLXPrinterServer::createPrinter( const OUString& rPrinterName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XPrinter > VCLXPrinterServer::createPrinter( const OUString& rPrinterName ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XPrinter > xP;
+ css::uno::Reference< css::awt::XPrinter > xP;
xP = new VCLXPrinter( rPrinterName );
return xP;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XInfoPrinter > VCLXPrinterServer::createInfoPrinter( const OUString& rPrinterName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XInfoPrinter > VCLXPrinterServer::createInfoPrinter( const OUString& rPrinterName ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XInfoPrinter > xP;
+ css::uno::Reference< css::awt::XInfoPrinter > xP;
xP = new VCLXInfoPrinter( rPrinterName );
return xP;
}
diff --git a/toolkit/source/awt/vclxregion.cxx b/toolkit/source/awt/vclxregion.cxx
index c2344b7..2fd56d4 100644
--- a/toolkit/source/awt/vclxregion.cxx
+++ b/toolkit/source/awt/vclxregion.cxx
@@ -37,76 +37,76 @@ VCLXRegion::~VCLXRegion()
{
}
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXRegion::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXRegion::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XRegion* >(this)),
- (static_cast< ::com::sun::star::lang::XUnoTunnel* >(this)),
- (static_cast< ::com::sun::star::lang::XTypeProvider* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XRegion* >(this)),
+ (static_cast< css::lang::XUnoTunnel* >(this)),
+ (static_cast< css::lang::XTypeProvider* >(this)) );
return (aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType ));
}
-// ::com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
IMPL_XUNOTUNNEL( VCLXRegion )
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXRegion )
- cppu::UnoType<com::sun::star::awt::XRegion>::get()
+ cppu::UnoType<css::awt::XRegion>::get()
IMPL_XTYPEPROVIDER_END
-::com::sun::star::awt::Rectangle VCLXRegion::getBounds() throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::Rectangle VCLXRegion::getBounds() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
return AWTRectangle( maRegion.GetBoundRect() );
}
-void VCLXRegion::clear() throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::clear() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.SetEmpty();
}
-void VCLXRegion::move( sal_Int32 nHorzMove, sal_Int32 nVertMove ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::move( sal_Int32 nHorzMove, sal_Int32 nVertMove ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.Move( nHorzMove, nVertMove );
}
-void VCLXRegion::unionRectangle( const ::com::sun::star::awt::Rectangle& rRect ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::unionRectangle( const css::awt::Rectangle& rRect ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.Union( VCLRectangle( rRect ) );
}
-void VCLXRegion::intersectRectangle( const ::com::sun::star::awt::Rectangle& rRect ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::intersectRectangle( const css::awt::Rectangle& rRect ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.Intersect( VCLRectangle( rRect ) );
}
-void VCLXRegion::excludeRectangle( const ::com::sun::star::awt::Rectangle& rRect ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::excludeRectangle( const css::awt::Rectangle& rRect ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.Exclude( VCLRectangle( rRect ) );
}
-void VCLXRegion::xOrRectangle( const ::com::sun::star::awt::Rectangle& rRect ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::xOrRectangle( const css::awt::Rectangle& rRect ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
maRegion.XOr( VCLRectangle( rRect ) );
}
-void VCLXRegion::unionRegion( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XRegion >& rxRegion ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::unionRegion( const css::uno::Reference< css::awt::XRegion >& rxRegion ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -114,7 +114,7 @@ void VCLXRegion::unionRegion( const ::com::sun::star::uno::Reference< ::com::sun
maRegion.Union( VCLUnoHelper::GetRegion( rxRegion ) );
}
-void VCLXRegion::intersectRegion( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XRegion >& rxRegion ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::intersectRegion( const css::uno::Reference< css::awt::XRegion >& rxRegion ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -122,7 +122,7 @@ void VCLXRegion::intersectRegion( const ::com::sun::star::uno::Reference< ::com:
maRegion.Intersect( VCLUnoHelper::GetRegion( rxRegion ) );
}
-void VCLXRegion::excludeRegion( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XRegion >& rxRegion ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::excludeRegion( const css::uno::Reference< css::awt::XRegion >& rxRegion ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -130,7 +130,7 @@ void VCLXRegion::excludeRegion( const ::com::sun::star::uno::Reference< ::com::s
maRegion.Exclude( VCLUnoHelper::GetRegion( rxRegion ) );
}
-void VCLXRegion::xOrRegion( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XRegion >& rxRegion ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXRegion::xOrRegion( const css::uno::Reference< css::awt::XRegion >& rxRegion ) throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -138,7 +138,7 @@ void VCLXRegion::xOrRegion( const ::com::sun::star::uno::Reference< ::com::sun::
maRegion.XOr( VCLUnoHelper::GetRegion( rxRegion ) );
}
-::com::sun::star::uno::Sequence< ::com::sun::star::awt::Rectangle > VCLXRegion::getRectangles() throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< css::awt::Rectangle > VCLXRegion::getRectangles() throw(css::uno::RuntimeException, std::exception)
{
::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
@@ -146,7 +146,7 @@ void VCLXRegion::xOrRegion( const ::com::sun::star::uno::Reference< ::com::sun::
maRegion.GetRegionRectangles(aRectangles);
// sal_uLong nRects = maRegion.GetRectCount();
- ::com::sun::star::uno::Sequence< ::com::sun::star::awt::Rectangle > aRects(aRectangles.size());
+ css::uno::Sequence< css::awt::Rectangle > aRects(aRectangles.size());
sal_uInt32 a(0);
for(RectangleVector::const_iterator aRectIter(aRectangles.begin()); aRectIter != aRectangles.end(); ++aRectIter)
diff --git a/toolkit/source/awt/vclxsystemdependentwindow.cxx b/toolkit/source/awt/vclxsystemdependentwindow.cxx
index 1ee5600..4881191 100644
--- a/toolkit/source/awt/vclxsystemdependentwindow.cxx
+++ b/toolkit/source/awt/vclxsystemdependentwindow.cxx
@@ -49,26 +49,26 @@ VCLXSystemDependentWindow::~VCLXSystemDependentWindow()
{
}
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXSystemDependentWindow::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXSystemDependentWindow::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XSystemDependentWindowPeer* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XSystemDependentWindowPeer* >(this)) );
return (aRet.hasValue() ? aRet : VCLXWindow::queryInterface( rType ));
}
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXSystemDependentWindow )
- cppu::UnoType<com::sun::star::awt::XSystemDependentWindowPeer>::get(),
+ cppu::UnoType<css::awt::XSystemDependentWindowPeer>::get(),
VCLXWindow::getTypes()
IMPL_XTYPEPROVIDER_END
-::com::sun::star::uno::Any VCLXSystemDependentWindow::getWindowHandle( const ::com::sun::star::uno::Sequence< sal_Int8 >& /*ProcessId*/, sal_Int16 SystemType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Any VCLXSystemDependentWindow::getWindowHandle( const css::uno::Sequence< sal_Int8 >& /*ProcessId*/, sal_Int16 SystemType ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
// TODO, check the process id
- ::com::sun::star::uno::Any aRet;
+ css::uno::Any aRet;
vcl::Window* pWindow = GetWindow();
if ( pWindow )
{
@@ -76,12 +76,12 @@ IMPL_XTYPEPROVIDER_END
if( pSysData )
{
#if (defined WNT)
- if( SystemType == ::com::sun::star::lang::SystemDependent::SYSTEM_WIN32 )
+ if( SystemType == css::lang::SystemDependent::SYSTEM_WIN32 )
{
aRet <<= reinterpret_cast<sal_IntPtr>(pSysData->hWnd);
}
#elif (defined MACOSX)
- if( SystemType == ::com::sun::star::lang::SystemDependent::SYSTEM_MAC )
+ if( SystemType == css::lang::SystemDependent::SYSTEM_MAC )
{
aRet <<= reinterpret_cast<sal_IntPtr>(pSysData->mpNSView);
}
@@ -92,9 +92,9 @@ IMPL_XTYPEPROVIDER_END
// Nothing
(void) SystemType;
#elif (defined UNX)
- if( SystemType == ::com::sun::star::lang::SystemDependent::SYSTEM_XWINDOW )
+ if( SystemType == css::lang::SystemDependent::SYSTEM_XWINDOW )
{
- ::com::sun::star::awt::SystemDependentXWindow aSD;
+ css::awt::SystemDependentXWindow aSD;
aSD.DisplayPointer = sal::static_int_cast< sal_Int64 >(reinterpret_cast< sal_IntPtr >(pSysData->pDisplay));
aSD.WindowHandle = pSysData->aWindow;
aRet <<= aSD;
diff --git a/toolkit/source/awt/vclxtabpagecontainer.cxx b/toolkit/source/awt/vclxtabpagecontainer.cxx
index cd27901..2d29565 100644
--- a/toolkit/source/awt/vclxtabpagecontainer.cxx
+++ b/toolkit/source/awt/vclxtabpagecontainer.cxx
@@ -77,9 +77,9 @@ void SAL_CALL VCLXTabPageContainer::draw( sal_Int32 nX, sal_Int32 nY ) throw(Run
VCLXWindow::draw( nX, nY );
}
-::com::sun::star::awt::DeviceInfo VCLXTabPageContainer::getInfo() throw(RuntimeException, std::exception)
+css::awt::DeviceInfo VCLXTabPageContainer::getInfo() throw(RuntimeException, std::exception)
{
- ::com::sun::star::awt::DeviceInfo aInfo = VCLXDevice::getInfo();
+ css::awt::DeviceInfo aInfo = VCLXDevice::getInfo();
return aInfo;
}
@@ -115,17 +115,17 @@ sal_Bool SAL_CALL VCLXTabPageContainer::isTabPageActive( ::sal_Int16 tabPageInde
return (getActiveTabPageID() == tabPageIndex);
}
-Reference< ::com::sun::star::awt::tab::XTabPage > SAL_CALL VCLXTabPageContainer::getTabPage( ::sal_Int16 tabPageIndex ) throw (RuntimeException, std::exception)
+Reference< css::awt::tab::XTabPage > SAL_CALL VCLXTabPageContainer::getTabPage( ::sal_Int16 tabPageIndex ) throw (RuntimeException, std::exception)
{
return (tabPageIndex >= 0 && tabPageIndex < static_cast<sal_Int16>(m_aTabPages.size())) ? m_aTabPages[tabPageIndex] : NULL;
}
-Reference< ::com::sun::star::awt::tab::XTabPage > SAL_CALL VCLXTabPageContainer::getTabPageByID( ::sal_Int16 tabPageID ) throw (RuntimeException, std::exception)
+Reference< css::awt::tab::XTabPage > SAL_CALL VCLXTabPageContainer::getTabPageByID( ::sal_Int16 tabPageID ) throw (RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- Reference< ::com::sun::star::awt::tab::XTabPage > xTabPage;
- ::std::vector< Reference< ::com::sun::star::awt::tab::XTabPage > >::iterator aIter = m_aTabPages.begin();
- ::std::vector< Reference< ::com::sun::star::awt::tab::XTabPage > >::iterator aEnd = m_aTabPages.end();
+ Reference< css::awt::tab::XTabPage > xTabPage;
+ ::std::vector< Reference< css::awt::tab::XTabPage > >::iterator aIter = m_aTabPages.begin();
+ ::std::vector< Reference< css::awt::tab::XTabPage > >::iterator aEnd = m_aTabPages.end();
for(;aIter != aEnd;++aIter)
{
Reference< awt::XControl > xControl(*aIter,UNO_QUERY );
@@ -139,12 +139,12 @@ Reference< ::com::sun::star::awt::tab::XTabPage > SAL_CALL VCLXTabPageContainer:
return xTabPage;
}
-void SAL_CALL VCLXTabPageContainer::addTabPageContainerListener( const Reference< ::com::sun::star::awt::tab::XTabPageContainerListener >& listener ) throw (RuntimeException, std::exception)
+void SAL_CALL VCLXTabPageContainer::addTabPageContainerListener( const Reference< css::awt::tab::XTabPageContainerListener >& listener ) throw (RuntimeException, std::exception)
{
m_aTabPageListeners.addInterface( listener );
}
-void SAL_CALL VCLXTabPageContainer::removeTabPageContainerListener( const Reference< ::com::sun::star::awt::tab::XTabPageContainerListener >& listener ) throw (RuntimeException, std::exception)
+void SAL_CALL VCLXTabPageContainer::removeTabPageContainerListener( const Reference< css::awt::tab::XTabPageContainerListener >& listener ) throw (RuntimeException, std::exception)
... etc. - the rest is truncated
More information about the Libreoffice-commits
mailing list
diff --git a/toolkit/source/awt/vclxcontainer.cxx b/toolkit/source/awt/vclxcontainer.cxx
index ca66dbc..42b98bb 100644
--- a/toolkit/source/awt/vclxcontainer.cxx
+++ b/toolkit/source/awt/vclxcontainer.cxx
@@ -47,57 +47,57 @@ VCLXContainer::~VCLXContainer()
{
}
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXContainer::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXContainer::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XVclContainer* >(this)),
- (static_cast< ::com::sun::star::awt::XVclContainerPeer* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XVclContainer* >(this)),
+ (static_cast< css::awt::XVclContainerPeer* >(this)) );
return (aRet.hasValue() ? aRet : VCLXWindow::queryInterface( rType ));
}
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXContainer )
- cppu::UnoType<com::sun::star::awt::XVclContainer>::get(),
- cppu::UnoType<com::sun::star::awt::XVclContainerPeer>::get(),
+ cppu::UnoType<css::awt::XVclContainer>::get(),
+ cppu::UnoType<css::awt::XVclContainerPeer>::get(),
VCLXWindow::getTypes()
IMPL_XTYPEPROVIDER_END
-// ::com::sun::star::awt::XVclContainer
-void VCLXContainer::addVclContainerListener( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XVclContainerListener >& rxListener ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XVclContainer
+void VCLXContainer::addVclContainerListener( const css::uno::Reference< css::awt::XVclContainerListener >& rxListener ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
GetContainerListeners().addInterface( rxListener );
}
-void VCLXContainer::removeVclContainerListener( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XVclContainerListener >& rxListener ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXContainer::removeVclContainerListener( const css::uno::Reference< css::awt::XVclContainerListener >& rxListener ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
GetContainerListeners().removeInterface( rxListener );
}
-::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > > VCLXContainer::getWindows( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< css::uno::Reference< css::awt::XWindow > > VCLXContainer::getWindows( ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
// Request container interface from all children
- ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > > aSeq;
+ css::uno::Sequence< css::uno::Reference< css::awt::XWindow > > aSeq;
vcl::Window* pWindow = GetWindow();
if ( pWindow )
{
sal_uInt16 nChildren = pWindow->GetChildCount();
if ( nChildren )
{
- aSeq = ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > >( nChildren );
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > * pChildRefs = aSeq.getArray();
+ aSeq = css::uno::Sequence< css::uno::Reference< css::awt::XWindow > >( nChildren );
+ css::uno::Reference< css::awt::XWindow > * pChildRefs = aSeq.getArray();
for ( sal_uInt16 n = 0; n < nChildren; n++ )
{
vcl::Window* pChild = pWindow->GetChild( n );
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindowPeer > xWP = pChild->GetComponentInterface();
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > xW( xWP, ::com::sun::star::uno::UNO_QUERY );
+ css::uno::Reference< css::awt::XWindowPeer > xWP = pChild->GetComponentInterface();
+ css::uno::Reference< css::awt::XWindow > xW( xWP, css::uno::UNO_QUERY );
pChildRefs[n] = xW;
}
}
@@ -106,8 +106,8 @@ void VCLXContainer::removeVclContainerListener( const ::com::sun::star::uno::Ref
}
-// ::com::sun::star::awt::XVclContainerPeer
-void VCLXContainer::enableDialogControl( sal_Bool bEnable ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XVclContainerPeer
+void VCLXContainer::enableDialogControl( sal_Bool bEnable ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
@@ -123,21 +123,21 @@ void VCLXContainer::enableDialogControl( sal_Bool bEnable ) throw(::com::sun::st
}
}
-void VCLXContainer::setTabOrder( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > >& Components, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& Tabs, sal_Bool bGroupControl ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXContainer::setTabOrder( const css::uno::Sequence< css::uno::Reference< css::awt::XWindow > >& Components, const css::uno::Sequence< css::uno::Any >& Tabs, sal_Bool bGroupControl ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
sal_uInt32 nCount = Components.getLength();
DBG_ASSERT( nCount == (sal_uInt32)Tabs.getLength(), "setTabOrder: TabCount != ComponentCount" );
- const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > * pComps = Components.getConstArray();
- const ::com::sun::star::uno::Any* pTabs = Tabs.getConstArray();
+ const css::uno::Reference< css::awt::XWindow > * pComps = Components.getConstArray();
+ const css::uno::Any* pTabs = Tabs.getConstArray();
vcl::Window* pPrevWin = NULL;
for ( sal_uInt32 n = 0; n < nCount; n++ )
{
- // ::com::sun::star::style::TabStop
+ // css::style::TabStop
vcl::Window* pWin = VCLUnoHelper::GetWindow( pComps[n] );
// May be NULL if a ::com::sun::star::uno::Sequence is originated from TabController and is missing a peer!
if ( pWin )
{
// Order windows before manipulating their style, because elements such as the
@@ -147,7 +147,7 @@ void VCLXContainer::setTabOrder( const ::com::sun::star::uno::Sequence< ::com::s
WinBits nStyle = pWin->GetStyle();
nStyle &= ~(WB_TABSTOP|WB_NOTABSTOP|WB_GROUP);
- if ( pTabs[n].getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_BOOLEAN )
+ if ( pTabs[n].getValueType().getTypeClass() == css::uno::TypeClass_BOOLEAN )
{
bool bTab = false;
pTabs[n] >>= bTab;
@@ -168,12 +168,12 @@ void VCLXContainer::setTabOrder( const ::com::sun::star::uno::Sequence< ::com::s
}
}
-void VCLXContainer::setGroup( const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > >& Components ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void VCLXContainer::setGroup( const css::uno::Sequence< css::uno::Reference< css::awt::XWindow > >& Components ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
sal_uInt32 nCount = Components.getLength();
- const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > * pComps = Components.getConstArray();
+ const css::uno::Reference< css::awt::XWindow > * pComps = Components.getConstArray();
vcl::Window* pPrevWin = NULL;
vcl::Window* pPrevRadio = NULL;
@@ -227,8 +227,8 @@ void VCLXContainer::setGroup( const ::com::sun::star::uno::Sequence< ::com::sun:
void SAL_CALL VCLXContainer::setProperty(
const OUString& PropertyName,
- const ::com::sun::star::uno::Any& Value )
-throw(::com::sun::star::uno::RuntimeException, std::exception)
+ const css::uno::Any& Value )
+throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
@@ -123,21 +123,21 @@ void VCLXContainer::enableDialogControl( sal_Bool bEnable ) throw(::com::sun::st
vcl::Window* pWin = VCLUnoHelper::GetWindow( pComps[n] );
- // May be NULL if a ::com::sun::star::uno::Sequence is originated from TabController and is missing a peer!
+ // May be NULL if a css::uno::Sequence is originated from TabController and is missing a peer!
if ( pWin )
{
diff --git a/toolkit/source/awt/vclxdevice.cxx b/toolkit/source/awt/vclxdevice.cxx
index aff2261..70c8af9 100644
--- a/toolkit/source/awt/vclxdevice.cxx
+++ b/toolkit/source/awt/vclxdevice.cxx
@@ -63,33 +63,33 @@ void VCLXDevice::SetCreatedWithToolkit( bool bCreatedWithToolkit )
nFlags &= ~FLAGS_CREATEDWITHTOOLKIT;
}
-// ::com::sun::star::uno::XInterface
-::com::sun::star::uno::Any VCLXDevice::queryInterface( const ::com::sun::star::uno::Type & rType ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::uno::XInterface
+css::uno::Any VCLXDevice::queryInterface( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
{
- ::com::sun::star::uno::Any aRet = ::cppu::queryInterface( rType,
- (static_cast< ::com::sun::star::awt::XDevice* >(this)),
- (static_cast< ::com::sun::star::lang::XUnoTunnel* >(this)),
- (static_cast< ::com::sun::star::lang::XTypeProvider* >(this)),
- (static_cast< ::com::sun::star::awt::XUnitConversion* >(this)) );
+ css::uno::Any aRet = ::cppu::queryInterface( rType,
+ (static_cast< css::awt::XDevice* >(this)),
+ (static_cast< css::lang::XUnoTunnel* >(this)),
+ (static_cast< css::lang::XTypeProvider* >(this)),
+ (static_cast< css::awt::XUnitConversion* >(this)) );
return (aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType ));
}
-// ::com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
IMPL_XUNOTUNNEL( VCLXDevice )
-// ::com::sun::star::lang::XTypeProvider
+// css::lang::XTypeProvider
IMPL_XTYPEPROVIDER_START( VCLXDevice )
- cppu::UnoType<com::sun::star::awt::XDevice>::get(),
- cppu::UnoType<com::sun::star::awt::XUnitConversion>::get()
+ cppu::UnoType<css::awt::XDevice>::get(),
+ cppu::UnoType<css::awt::XUnitConversion>::get()
IMPL_XTYPEPROVIDER_END
-// ::com::sun::star::awt::XDevice,
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XGraphics > VCLXDevice::createGraphics( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+// css::awt::XDevice,
+css::uno::Reference< css::awt::XGraphics > VCLXDevice::createGraphics( ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XGraphics > xRef;
+ css::uno::Reference< css::awt::XGraphics > xRef;
if ( mpOutputDevice )
xRef = mpOutputDevice->CreateUnoGraphics();
@@ -97,11 +97,11 @@ IMPL_XTYPEPROVIDER_END
return xRef;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > VCLXDevice::createDevice( sal_Int32 nWidth, sal_Int32 nHeight ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XDevice > VCLXDevice::createDevice( sal_Int32 nWidth, sal_Int32 nHeight ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDevice > xRef;
+ css::uno::Reference< css::awt::XDevice > xRef;
if ( GetOutputDevice() )
{
VCLXVirtualDevice* pVDev = new VCLXVirtualDevice;
@@ -113,11 +113,11 @@ IMPL_XTYPEPROVIDER_END
return xRef;
}
-::com::sun::star::awt::DeviceInfo VCLXDevice::getInfo() throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::DeviceInfo VCLXDevice::getInfo() throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::awt::DeviceInfo aInfo;
+ css::awt::DeviceInfo aInfo;
if( mpOutputDevice )
{
@@ -158,24 +158,24 @@ IMPL_XTYPEPROVIDER_END
aInfo.Capabilities = 0;
if ( mpOutputDevice->GetOutDevType() != OUTDEV_PRINTER )
- aInfo.Capabilities = ::com::sun::star::awt::DeviceCapability::RASTEROPERATIONS|::com::sun::star::awt::DeviceCapability::GETBITS;
+ aInfo.Capabilities = css::awt::DeviceCapability::RASTEROPERATIONS|css::awt::DeviceCapability::GETBITS;
}
return aInfo;
}
-::com::sun::star::uno::Sequence< ::com::sun::star::awt::FontDescriptor > VCLXDevice::getFontDescriptors( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< css::awt::FontDescriptor > VCLXDevice::getFontDescriptors( ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::uno::Sequence< ::com::sun::star::awt::FontDescriptor> aFonts;
+ css::uno::Sequence< css::awt::FontDescriptor> aFonts;
if( mpOutputDevice )
{
int nFonts = mpOutputDevice->GetDevFontCount();
if ( nFonts )
{
- aFonts = ::com::sun::star::uno::Sequence< ::com::sun::star::awt::FontDescriptor>( nFonts );
- ::com::sun::star::awt::FontDescriptor* pFonts = aFonts.getArray();
+ aFonts = css::uno::Sequence< css::awt::FontDescriptor>( nFonts );
+ css::awt::FontDescriptor* pFonts = aFonts.getArray();
for ( int n = 0; n < nFonts; n++ )
pFonts[n] = VCLUnoHelper::CreateFontDescriptor( mpOutputDevice->GetDevFont( n ) );
}
@@ -183,11 +183,11 @@ IMPL_XTYPEPROVIDER_END
return aFonts;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont > VCLXDevice::getFont( const ::com::sun::star::awt::FontDescriptor& rDescriptor ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XFont > VCLXDevice::getFont( const css::awt::FontDescriptor& rDescriptor ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont > xRef;
+ css::uno::Reference< css::awt::XFont > xRef;
if( mpOutputDevice )
{
VCLXFont* pMetric = new VCLXFont;
@@ -197,11 +197,11 @@ IMPL_XTYPEPROVIDER_END
return xRef;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XBitmap > VCLXDevice::createBitmap( sal_Int32 nX, sal_Int32 nY, sal_Int32 nWidth, sal_Int32 nHeight ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XBitmap > VCLXDevice::createBitmap( sal_Int32 nX, sal_Int32 nY, sal_Int32 nWidth, sal_Int32 nHeight ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XBitmap > xBmp;
+ css::uno::Reference< css::awt::XBitmap > xBmp;
if( mpOutputDevice )
{
Bitmap aBmp = mpOutputDevice->GetBitmap( Point( nX, nY ), Size( nWidth, nHeight ) );
@@ -213,14 +213,14 @@ IMPL_XTYPEPROVIDER_END
return xBmp;
}
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XDisplayBitmap > VCLXDevice::createDisplayBitmap( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XBitmap >& rxBitmap ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::awt::XDisplayBitmap > VCLXDevice::createDisplayBitmap( const css::uno::Reference< css::awt::XBitmap >& rxBitmap ) throw(css::uno::RuntimeException, std::exception)
{
SolarMutexGuard aGuard;
BitmapEx aBmp = VCLUnoHelper::GetBitmap( rxBitmap );
VCLXBitmap* pBmp = new VCLXBitmap;
pBmp->SetBitmap( aBmp );
- ::com::sun::star::uno::Reference< ::com::sun::star::awt::XDisplayBitmap > xDBmp = pBmp;
+ css::uno::Reference< css::awt::XDisplayBitmap > xDBmp = pBmp;
return xDBmp;
}
@@ -231,19 +231,19 @@ VCLXVirtualDevice::~VCLXVirtualDevice()
mpOutputDevice.disposeAndClear();
}
-// Interface implementation of ::com::sun::star::awt::XUnitConversion
+// Interface implementation of css::awt::XUnitConversion
-::com::sun::star::awt::Point SAL_CALL VCLXDevice::convertPointToLogic( const ::com::sun::star::awt::Point& aPoint, ::sal_Int16 TargetUnit ) throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::Point SAL_CALL VCLXDevice::convertPointToLogic( const css::awt::Point& aPoint, ::sal_Int16 TargetUnit ) throw (css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
(void)aPoint;
SolarMutexGuard aGuard;
- if (TargetUnit == com::sun::star::util::MeasureUnit::PERCENT )
+ if (TargetUnit == css::util::MeasureUnit::PERCENT )
{
// percentage not allowed here
- throw ::com::sun::star::lang::IllegalArgumentException();
+ throw css::lang::IllegalArgumentException();
}
- ::com::sun::star::awt::Point aAWTPoint(0,0);
+ css::awt::Point aAWTPoint(0,0);
// X,Y
if( mpOutputDevice )
@@ -258,18 +258,18 @@ VCLXVirtualDevice::~VCLXVirtualDevice()
}
-::com::sun::star::awt::Point SAL_CALL VCLXDevice::convertPointToPixel( const ::com::sun::star::awt::Point& aPoint, ::sal_Int16 SourceUnit ) throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::Point SAL_CALL VCLXDevice::convertPointToPixel( const css::awt::Point& aPoint, ::sal_Int16 SourceUnit ) throw (css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
(void)aPoint;
SolarMutexGuard aGuard;
- if (SourceUnit == com::sun::star::util::MeasureUnit::PERCENT ||
- SourceUnit == com::sun::star::util::MeasureUnit::PIXEL )
+ if (SourceUnit == css::util::MeasureUnit::PERCENT ||
+ SourceUnit == css::util::MeasureUnit::PIXEL )
{
// pixel or percentage not allowed here
- throw ::com::sun::star::lang::IllegalArgumentException();
+ throw css::lang::IllegalArgumentException();
}
- ::com::sun::star::awt::Point aAWTPoint(0,0);
+ css::awt::Point aAWTPoint(0,0);
if( mpOutputDevice )
{
@@ -282,17 +282,17 @@ VCLXVirtualDevice::~VCLXVirtualDevice()
return aAWTPoint;
}
-::com::sun::star::awt::Size SAL_CALL VCLXDevice::convertSizeToLogic( const ::com::sun::star::awt::Size& aSize, ::sal_Int16 TargetUnit ) throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::Size SAL_CALL VCLXDevice::convertSizeToLogic( const css::awt::Size& aSize, ::sal_Int16 TargetUnit ) throw (css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
(void)aSize;
SolarMutexGuard aGuard;
- if (TargetUnit == com::sun::star::util::MeasureUnit::PERCENT)
+ if (TargetUnit == css::util::MeasureUnit::PERCENT)
{
// percentage not allowed here
- throw ::com::sun::star::lang::IllegalArgumentException();
+ throw css::lang::IllegalArgumentException();
}
- ::com::sun::star::awt::Size aAWTSize(0,0);
+ css::awt::Size aAWTSize(0,0);
// Width, Height
@@ -307,18 +307,18 @@ VCLXVirtualDevice::~VCLXVirtualDevice()
return aAWTSize;
}
-::com::sun::star::awt::Size SAL_CALL VCLXDevice::convertSizeToPixel( const ::com::sun::star::awt::Size& aSize, ::sal_Int16 SourceUnit ) throw (::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::awt::Size SAL_CALL VCLXDevice::convertSizeToPixel( const css::awt::Size& aSize, ::sal_Int16 SourceUnit ) throw (css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
{
(void)aSize;
SolarMutexGuard aGuard;
- if (SourceUnit == com::sun::star::util::MeasureUnit::PERCENT ||
- SourceUnit == com::sun::star::util::MeasureUnit::PIXEL)
+ if (SourceUnit == css::util::MeasureUnit::PERCENT ||
+ SourceUnit == css::util::MeasureUnit::PIXEL)
{
// pixel or percentage not allowed here
- throw ::com::sun::star::lang::IllegalArgumentException();
+ throw css::lang::IllegalArgumentException();
}
- ::com::sun::star::awt::Size aAWTSize(0,0);
+ css::awt::Size aAWTSize(0,0);
// Width, Height
if( mpOutputDevice )
{